abacusai.training_config_options — AbacusAI documentation

# abacusai.training_config_options

## Classes

`TrainingConfigOptions` | Training options for a model

## Module Contents

class abacusai.training_config_options.TrainingConfigOptions(client, name=None, dataType=None, valueType=None, valueOptions=None, value=None, default=None, options=None, description=None, required=None, lastModelValue=None, needsRefresh=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Training options for a model

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the parameter

    - dataType (str) – The type of input required for this option

    - valueType (str) – If the data_type is of type DICT_VALUES, this field specifies the expected value type of the values

    - valueOptions (list[str]) – The list of valid values for DICT_VALUES

    - value (optional[str, int, float, bool]) – The value of this option

    - default (optional[str, int, float, bool]) – The default value for this option

    - options (list[dict]) – A list of options for this parameter

    - description (str) – A description of the parameter

    - required (bool) – True if the parameter is required for training

    - lastModelValue (optional[str, int, float, bool]) – The last value used to train a model in this project

    - needsRefresh (bool) – True if training config needs to be fetched again when this config option is changed

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict